@@ -10,11 +10,9 @@ genList = []
 
 
 class Generator:
-    def __init__(self, title, id, generalProb, generalSol, func, kwargs):
+    def __init__(self, title, id, func, kwargs):
         self.title = title
         self.id = id
-        self.generalProb = generalProb
-        self.generalSol = generalSol
         self.func = func
         self.kwargs = kwargs
 
@@ -28,18 +26,10 @@ class Generator:
         genList.append([id, title, self, funcname, subjectname, kwargs])
 
     def __str__(self):
-        return str(
-            self.id
-        ) + " " + self.title + " " + self.generalProb + " " + self.generalSol
+        return str(self.id) + " " + self.title
 
     def __call__(self, *args, **kwargs):
-        try:
-            return self.func(*args, **kwargs)
-        except TypeError:
-            # If an error is thrown from kwargs, remove the style element
-            # This happens if someone trys to get style='latex' for an
-            del kwargs['style']
-            return self.func(*args, **kwargs)
+        return self.func(*args, **kwargs)
 
 
 def getGenList():
