@@ -1,7 +1,7 @@
 from .__init__ import *
 
 
-def likeTermCombineFunc(maxCoef=10, maxExp=20, maxTerms=10):
+def likeTermCombineFunc(maxCoef=10, maxExp=20, maxTerms=10, format='string'):
     numTerms = random.randint(1, maxTerms)
     problem = ""
     solution = ""
@@ -16,7 +16,10 @@ def likeTermCombineFunc(maxCoef=10, maxExp=20, maxTerms=10):
         problem += str(coefficient) + "x^" + str(exponent)
 
     solution = combineTerms(problem)
-    return problem, solution
+    if format == 'string':
+        return problem, solution
+    else:
+        return problem, solution
 
 
 def combineTerms(string):
@@ -41,5 +44,5 @@ def combineTerms(string):
     return final_string
 
 
-combine_like_terms = Generator("Combine Like terms", 105, "nx^m+lx^k+bx^m",
-                               "(n+b)x^m+lx^k", likeTermCombineFunc, ["maxCoef=10", "maxExp=20", "maxTerms=10"])
+combine_like_terms = Generator("Combine Like terms", 105, likeTermCombineFunc,
+                               ["maxCoef=10", "maxExp=20", "maxTerms=10"])
