@@ -1,7 +1,7 @@
 from .__init__ import *
 
 
-def factoringFunc(range_x1=10, range_x2=10):
+def factoringFunc(range_x1=10, range_x2=10, format='string'):
     x1 = random.randint(-range_x1, range_x1)
     x2 = random.randint(-range_x2, range_x2)
 
@@ -23,12 +23,14 @@ def factoringFunc(range_x1=10, range_x2=10):
     else:
         problem = f"x^2{b}x{c}"
 
-    x1 = intParser(x1)
-    x2 = intParser(x2)
-    solution = f"(x{x1})(x{x2})"
-    return problem, solution
+    if format == 'string':
+        x1 = intParser(x1)
+        x2 = intParser(x2)
+        solution = f"(x{x1})(x{x2})"
+        return problem, solution
+    else:
+        return b, c, x1, x2
 
 
-factoring = Generator("Factoring Quadratic", 21, "x^2+(x1+x2)+x1*x2",
-                      "(x-x1)(x-x2)", factoringFunc,
+factoring = Generator("Factoring Quadratic", 21, factoringFunc,
                       ["range_x1=10", "range_x2=10"])
