@@ -1,7 +1,7 @@
 from .__init__ import *
 
 
-def DecimalToBCDFunc(maxNumber=10000):
+def DecimalToBCDFunc(maxNumber=10000, format='string'):
     n = random.randint(1000, maxNumber)
     x = n
     # binstring = ''
@@ -17,6 +17,4 @@ def DecimalToBCDFunc(maxNumber=10000):
 
 
 decimal_to_bcd = Generator("Decimal to Binary Coded Decimal", 103,
-                           "Binary Coded Decimal of Decimal n is ", "b",
-                           DecimalToBCDFunc,
-                           ["maxNumber=10000"])
+                           DecimalToBCDFunc, ["maxNumber=10000"])
