@@ -1,7 +1,7 @@
 from .__init__ import *
 
 
-def DecimalToBinaryFunc(max_dec=99):
+def DecimalToBinaryFunc(max_dec=99, format='string'):
     a = random.randint(1, max_dec)
     b = bin(a).replace("0b", "")
 
@@ -11,6 +11,5 @@ def DecimalToBinaryFunc(max_dec=99):
     return problem, solution
 
 
-decimal_to_binary = Generator("Decimal to Binary", 14, "Binary of a=", "b",
-                              DecimalToBinaryFunc,
+decimal_to_binary = Generator("Decimal to Binary", 14, DecimalToBinaryFunc,
                               ["max_dec=99"])
