@@ -1,7 +1,7 @@
 from .__init__ import *
 
 
-def deciToHexaFunc(max_dec=1000):
+def deciToHexaFunc(max_dec=1000, format='string'):
     a = random.randint(0, max_dec)
     b = hex(a)
     problem = "Binary of " + str(a) + "="
@@ -10,6 +10,5 @@ def deciToHexaFunc(max_dec=1000):
     return problem, solution
 
 
-decimal_to_hexadeci = Generator("Decimal to Hexadecimal", 79, "Binary of a=",
-                                "b", deciToHexaFunc,
+decimal_to_hexadeci = Generator("Decimal to Hexadecimal", 79, deciToHexaFunc,
                                 ["max_dec=1000"])
