@@ -2,7 +2,7 @@ from .__init__ import *
 import math
 
 
-def angleBtwVectorsFunc(maxEltAmt=20):
+def angleBtwVectorsFunc(maxEltAmt=20, format='string'):
     s = 0
     v1 = [
         round(random.uniform(0, 1000), 2)
@@ -25,8 +25,5 @@ def angleBtwVectorsFunc(maxEltAmt=20):
     return problem, solution
 
 
-angle_btw_vectors = Generator(
-    "Angle between 2 vectors", 70,
-    "Angle Between 2 vectors V1=[v11, v12, ..., v1n] and V2=[v21, v22, ....., v2n]",
-    "V1.V2 / (euclidNorm(V1)*euclidNorm(V2))", angleBtwVectorsFunc,
-    ["maxEltAmt=20"])
+angle_btw_vectors = Generator("Angle between 2 vectors", 70,
+                              angleBtwVectorsFunc, ["maxEltAmt=20"])
