@@ -1,7 +1,7 @@
 from .__init__ import *
 
 
-def geometricMeanFunc(maxValue=100, maxNum=4):
+def geometricMeanFunc(maxValue=100, maxNum=4, format='string'):
     a = random.randint(1, maxValue)
     b = random.randint(1, maxValue)
     c = random.randint(1, maxValue)
@@ -27,8 +27,5 @@ def geometricMeanFunc(maxValue=100, maxNum=4):
     return problem, solution
 
 
-geometric_mean = Generator(
-    "Geometric Mean of N Numbers", 67,
-    "Geometric mean of n numbers A1 , A2 , ... , An = ",
-    "(A1*A2*...An)^(1/n) = ans", geometricMeanFunc,
-    ["maxValue=100", "maxNum=4"])
+geometric_mean = Generator("Geometric Mean of N Numbers", 67,
+                           geometricMeanFunc, ["maxValue=100", "maxNum=4"])
